summaryrefslogtreecommitdiff
path: root/src/libostree/ostree-core.h
diff options
context:
space:
mode:
authorColin Walters <walters@verbum.org>2017-09-21 15:48:46 -0400
committerAtomic Bot <atomic-devel@projectatomic.io>2017-09-21 22:17:55 +0000
commitee5ecf33a55fb22ef121d76721dea0297d712c8f (patch)
tree3fd57ed23e6973c4ceae36c4f9633f234019e97b /src/libostree/ostree-core.h
parent1797aff6a86770621d3ea9e0f725ad96754876b5 (diff)
downloadostree-ee5ecf33a55fb22ef121d76721dea0297d712c8f.tar.gz
lib: Define an alias OSTREE_REPO_MODE_ARCHIVE
For the old `OSTREE_REPO_MODE_ARCHIVE_Z2`. Use it mostly tree wide except for the repo finder tests (to avoid conflicting with some outstanding PRs). Just noted another user coming in some of those tests and wanted to do a cleanup. Closes: #1209 Approved by: jlebon
Diffstat (limited to 'src/libostree/ostree-core.h')
-rw-r--r--src/libostree/ostree-core.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/libostree/ostree-core.h b/src/libostree/ostree-core.h
index 5124814c..aae86d54 100644
--- a/src/libostree/ostree-core.h
+++ b/src/libostree/ostree-core.h
@@ -180,7 +180,8 @@ typedef enum {
/**
* OstreeRepoMode:
* @OSTREE_REPO_MODE_BARE: Files are stored as themselves; checkouts are hardlinks; can only be written as root
* @OSTREE_REPO_MODE_ARCHIVE_Z2: Files are compressed, should be owned by non-root. Can be served via HTTP
* @OSTREE_REPO_MODE_BARE_USER: Files are stored as themselves, except ownership; can be written by user. Hardlinks work only in user checkouts.
* @OSTREE_REPO_MODE_BARE_USER_ONLY: Same as BARE_USER, but all metadata is not stored, so it can only be used for user checkouts. Does not need xattrs.
*
@@ -189,7 +190,8 @@ typedef enum {
*/
typedef enum {
OSTREE_REPO_MODE_BARE,
- OSTREE_REPO_MODE_ARCHIVE_Z2,
+ OSTREE_REPO_MODE_ARCHIVE,
+ OSTREE_REPO_MODE_ARCHIVE_Z2 = OSTREE_REPO_MODE_ARCHIVE,
OSTREE_REPO_MODE_BARE_USER,
OSTREE_REPO_MODE_BARE_USER_ONLY,
} OstreeRepoMode;
@@ -180,7 +180,8 @@ typedef enum {
* OstreeRepoMode:
* @OSTREE_REPO_MODE_BARE: Files are stored as themselves; checkouts are hardlinks; can only be written as root
- * @OSTREE_REPO_MODE_ARCHIVE_Z2: Files are compressed, should be owned by non-root. Can be served via HTTP
+ * @OSTREE_REPO_MODE_ARCHIVE: Files are compressed, should be owned by non-root. Can be served via HTTP. Since: 2017.12
+ * @OSTREE_REPO_MODE_ARCHIVE_Z2: Legacy alias for `OSTREE_REPO_MODE_ARCHIVE`
* @OSTREE_REPO_MODE_BARE_USER: Files are stored as themselves, except ownership; can be written by user. Hardlinks work only in user checkouts.
* @OSTREE_REPO_MODE_BARE_USER_ONLY: Same as BARE_USER, but all metadata is not stored, so it can only be used for user checkouts. Does not need xattrs.